vfbLib.parsers.text.StringParser
================================

.. currentmodule:: vfbLib.parsers.text

.. autoclass:: StringParser
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~StringParser.__init__
      ~StringParser.parse
      ~StringParser.parse_hex
      ~StringParser.read_double
      ~StringParser.read_doubles
      ~StringParser.read_float
      ~StringParser.read_floats
      ~StringParser.read_int16
      ~StringParser.read_int32
      ~StringParser.read_int8
      ~StringParser.read_str
      ~StringParser.read_str_all
      ~StringParser.read_uint16
      ~StringParser.read_uint32
      ~StringParser.read_uint8
      ~StringParser.read_value
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~StringParser.encoding
      ~StringParser.master_count
      ~StringParser.stream
      ~StringParser.ttStemsH_count
      ~StringParser.ttStemsV_count
   
   